@@ -1607,33 +1607,33 @@ Grid::setFallingAmoebaScreenPosition (FallingAmoeba &fallingAmoeba,
             if (rotating)
             {
                 x -= (fallingAmoeba.y + 1 + directionX) * getAmoebaSize () -
-                    static_cast<uint16_t> (getAmoebaSize () * rotationX) +
-                    verticalOffset;
+                    static_cast<uint16_t> (getAmoebaSize () * rotationX);
                 y += (fallingAmoeba.x + directionY) * getAmoebaSize () +
                     static_cast<uint16_t> (getAmoebaSize () * rotationY);
             }
             else
             {
 
-                x -= (fallingAmoeba.y + 1) * getAmoebaSize () + verticalOffset;
+                x -= (fallingAmoeba.y + 1) * getAmoebaSize ();
                 y += fallingAmoeba.x * getAmoebaSize ();
             }
+            x -= verticalOffset - getAmoebaSize () * k_FirstVisibleHeight;
         }
         else
         {
             if ( rotating )
             {
                 x += (fallingAmoeba.y + directionX) * getAmoebaSize () -
-                    static_cast<uint16_t> (getAmoebaSize () * rotationX) +
-                    verticalOffset;
+                    static_cast<uint16_t> (getAmoebaSize () * rotationX);
                 y -= (fallingAmoeba.x + 1 + directionY) * getAmoebaSize () +
                     static_cast<uint16_t> (getAmoebaSize () * rotationY);
             }
             else
             {
-                x += fallingAmoeba.y * getAmoebaSize () + verticalOffset;
+                x += fallingAmoeba.y * getAmoebaSize ();
                 y -= (fallingAmoeba.x + 1) * getAmoebaSize ();
             }
+            x += verticalOffset - getAmoebaSize () * k_FirstVisibleHeight;
         }
     }
 
@@ -2034,7 +2034,7 @@ Grid::updateQueue (uint32_t elapsedTime)
                                     queueVerticalOffset);
             if ( 2 == amoebaNum || 3 == amoebaNum )
             {
-                (*currentAmoeba)->setX ((*currentAmoeba)->getX () -
+                (*currentAmoeba)->setY ((*currentAmoeba)->getY () -
                                         queueHorizontalOffset);
             }
         }
