@@ -371,39 +371,39 @@ TournamentSetupState::loadGraphicResources (void)
     {
         std::auto_ptr<Surface> faces (
                 Surface::fromFile (File::getGraphicsFilePath ("faces.png")));
-        for ( uint16_t currentCharacter = 0,
-                       x = static_cast<uint16_t> (k_FaceStartX * originalScale);
-              currentCharacter < 4 ;
-              currentCharacter++,
-                x += static_cast<uint16_t> (k_FaceSpan * originalScale) )
+        for ( uint16_t currentCharacter = 0 ; currentCharacter < 4 ;
+              currentCharacter++ )
         {
             faces->blit ((currentCharacter % k_FacesPerRow) * faceWidth, 0,
-                         faceWidth, faceHeight, x,
+                         faceWidth, faceHeight,
+                         static_cast<uint16_t> (
+                             getXPositionOfCol (currentCharacter) *
+                             originalScale),
                          static_cast<uint16_t> (k_FemaleFacesRowY *
                                                 originalScale),
                          m_Background->toSDLSurface());
         }
-        for ( uint16_t currentCharacter = 4,
-                       x = static_cast<uint16_t> (k_FaceStartX * originalScale);
-              currentCharacter < 8 ;
-              currentCharacter++,
-                x += static_cast<uint16_t> (k_FaceSpan * originalScale) )
+        for ( uint16_t currentCharacter = 4 ; currentCharacter < 8 ;
+              currentCharacter++ )
         {
             faces->blit ((currentCharacter % k_FacesPerRow) * faceWidth,
                          (currentCharacter / k_FacesPerRow) * faceHeight,
-                         faceWidth, faceHeight, x,
+                         faceWidth, faceHeight,
+                         static_cast<uint16_t> (
+                             getXPositionOfCol (currentCharacter - 4) *
+                             originalScale),
                          static_cast<uint16_t> (k_MaleFacesRowY *
                                                 originalScale),
                          m_Background->toSDLSurface());
         }
-        for ( uint16_t currentCharacter = 1,
-                       x = static_cast<uint16_t> (k_FaceStartX * originalScale);
-              currentCharacter < 7 ;
-              currentCharacter++,
-                x += static_cast<uint16_t> (k_FaceSpan * originalScale) )
+        for ( uint16_t currentCharacter = 1 ; currentCharacter < 7 ;
+              currentCharacter++ )
         {
             faces->blit ((currentCharacter % k_FacesPerRow) * faceWidth,
-                         faceHeight, faceWidth, faceHeight, x,
+                         faceHeight, faceWidth, faceHeight,
+                         static_cast<uint16_t> (
+                             getXPositionOfCol (currentCharacter - 1) *
+                             originalScale),
                          static_cast<uint16_t> (k_ComputerFacesRowY *
                                                 originalScale),
                          m_Background->toSDLSurface());
